@@ -1,4 +1,4 @@
-visreg2d <- function(fit, xvar, yvar, type=c("conditional", "contrast"), trans=I, scale=c("linear","response"),
+visreg2d <- function(fit, xvar, yvar, type=c("conditional", "contrast"), data=NULL, trans=I, scale=c("linear","response"),
                      nn=99, cond=list(), plot=TRUE, ...) {
   # Setup
   if (type[1]=="effect") {
@@ -11,7 +11,7 @@ visreg2d <- function(fit, xvar, yvar, type=c("conditional", "contrast"), trans=I
   if (missing(xvar) | missing(yvar)) stop("Must specify and x and y variable")
 
   # Set up f
-  f <- setupF(fit, c(xvar, yvar), parent.frame())
+  f <- setupF(fit, c(xvar, yvar), parent.frame(), data)
   if (attr(f, "needsUpdate")) fit <- update(fit, data=f)
   cond <- setupCond(cond, f)[[1]]
 
